@@ -16,7 +16,8 @@
 #include <apt-pkg/error.h>
 #include <apt-pkg/sptr.h>
 #include <apt-pkg/algorithms.h>
-    
+#include <apt-pkg/configuration.h>
+
 #include <apti18n.h>    
 									/*}}}*/
 
@@ -57,8 +58,8 @@ bool pkgDepCache::Init(OpProgress *Prog)
    if (Prog != 0)
    {
       Prog->OverallProgress(0,2*Head().PackageCount,Head().PackageCount,
-			    _("Building Dependency Tree"));
-      Prog->SubProgress(Head().PackageCount,_("Candidate Versions"));
+			    _("Building dependency tree"));
+      Prog->SubProgress(Head().PackageCount,_("Candidate versions"));
    }
    
    /* Set the current state of everything. In this state all of the
@@ -86,11 +87,14 @@ bool pkgDepCache::Init(OpProgress *Prog)
       
       Prog->OverallProgress(Head().PackageCount,2*Head().PackageCount,
 			    Head().PackageCount,
-			    _("Building Dependency Tree"));
-      Prog->SubProgress(Head().PackageCount,_("Dependency Generation"));
+			    _("Building dependency tree"));
+      Prog->SubProgress(Head().PackageCount,_("Dependency generation"));
    }
    
    Update(Prog);
+
+   if(Prog != 0)
+      Prog->Done();
    
    return true;
 } 
@@ -709,6 +713,10 @@ void pkgDepCache::MarkInstall(PkgIterator const &Pkg,bool AutoInst,
 	 
 	 if (InstPkg.end() == false)
 	 {
+	    if(_config->FindB("Debug::pkgDepCache::AutoInstall",false) == true)
+	       std::clog << "Installing " << InstPkg.Name() 
+			 << " as dep of " << Pkg.Name() 
+			 << std::endl;
 	    MarkInstall(InstPkg,true,Depth + 1);
 
 	    // Set the autoflag, after MarkInstall because MarkInstall unsets it
